@@ -8,7 +8,7 @@
 
 double osa_dist(unsigned int *, int, unsigned int *, int, double *, double *);
 dictionary *new_dictionary(unsigned int);
-void free_dictionary();
+void free_dictionary(dictionary *);
 double dl_dist(unsigned int *, int, unsigned int *, int, double *, dictionary *, double *);
 double hamming_dist(unsigned int *, int, unsigned int *, int);
 double lcs_dist(unsigned int *, int, unsigned int *, int, double *);
@@ -16,8 +16,8 @@ double lv_dist(unsigned int *, int, unsigned int *, int, double *, double *);
 double osa_dist(unsigned int *, int, unsigned int *, int, double *, double *);
 double jaro_winkler_dist(unsigned int *, int, unsigned int *, int, double, double, double *, double *);
 qtree *new_qtree(int, int);
-void free_qtree();
-double qgram_dist(unsigned int *, int, unsigned int *t, int, unsigned int, qtree **, int);
+void free_qtree(qtree *);
+double qgram_dist(unsigned int *, int, unsigned int *, int, unsigned int, qtree **, int);
 double soundex_dist(unsigned int *, int, unsigned int *, int, unsigned int *);
-
+double running_cosine_dist(unsigned int *, int, unsigned int *, int, unsigned int, qtree **, double *);
 #endif
